Responsive examples - Child row control

# Responsive example Child row control

When a column is removed from display by Responsive, the data is still available in the table and can be displayed in a DataTables child row (see `row().child()`). By default Responsive will show child row controls in the first column when the table has been collapsed, allowing the end user to show / hide the information from the hidden columns.

Responsive has a number of options for display of the child rows:

- If child row display is enabled: `responsive.details`
- How the show / hide control is displayed: `responsive.details.type`
- How the child row is rendered: `responsive.details.renderer`

This section shows examples of these options being used.